# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 1.41.3
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class InternalTransferTransactionSubtypes(str, Enum):
    """
    The set of valid INTERNAL_TRANSFER transaction subtypes
    """

    """
    allowed enum values
    """
    ACCOUNT_DECREASE_LIMIT = 'ACCOUNT_DECREASE_LIMIT'
    ACCOUNT_DECREASE_LIMIT_REVERSAL = 'ACCOUNT_DECREASE_LIMIT_REVERSAL'
    ACCOUNT_INCREASE_LIMIT = 'ACCOUNT_INCREASE_LIMIT'
    ACCOUNT_INCREASE_LIMIT_REVERSAL = 'ACCOUNT_INCREASE_LIMIT_REVERSAL'
    ACCOUNT_TO_ACCOUNT = 'ACCOUNT_TO_ACCOUNT'
    ACCOUNT_TO_ACCOUNT_REVERSAL = 'ACCOUNT_TO_ACCOUNT_REVERSAL'
    ACCOUNT_TO_ACCOUNT_SWEEP = 'ACCOUNT_TO_ACCOUNT_SWEEP'
    ACCOUNT_TO_ACCOUNT_SWEEP_REVERSAL = 'ACCOUNT_TO_ACCOUNT_SWEEP_REVERSAL'
    ACH_CREDIT_SWEEP = 'ACH_CREDIT_SWEEP'
    ACH_CREDIT_SWEEP_REVERSAL = 'ACH_CREDIT_SWEEP_REVERSAL'
    ACH_DEBIT_SWEEP = 'ACH_DEBIT_SWEEP'
    ACH_DEBIT_SWEEP_REVERSAL = 'ACH_DEBIT_SWEEP_REVERSAL'
    ACH_FLOAT_TRANSFER = 'ACH_FLOAT_TRANSFER'
    ACH_FLOAT_TRANSFER_REVERSAL = 'ACH_FLOAT_TRANSFER_REVERSAL'
    ACH_INCOMING_CREDIT_SWEEP = 'ACH_INCOMING_CREDIT_SWEEP'
    ACH_INCOMING_CREDIT_SWEEP_REVERSAL = 'ACH_INCOMING_CREDIT_SWEEP_REVERSAL'
    ACH_INCOMING_DEBIT_SWEEP = 'ACH_INCOMING_DEBIT_SWEEP'
    ACH_INCOMING_DEBIT_SWEEP_REVERSAL = 'ACH_INCOMING_DEBIT_SWEEP_REVERSAL'
    ACH_INCOMING_RETURN_CREDIT_SWEEP = 'ACH_INCOMING_RETURN_CREDIT_SWEEP'
    ACH_INCOMING_RETURN_CREDIT_SWEEP_REVERSAL = 'ACH_INCOMING_RETURN_CREDIT_SWEEP_REVERSAL'
    ACH_INCOMING_RETURN_DEBIT_SWEEP = 'ACH_INCOMING_RETURN_DEBIT_SWEEP'
    ACH_INCOMING_RETURN_DEBIT_SWEEP_REVERSAL = 'ACH_INCOMING_RETURN_DEBIT_SWEEP_REVERSAL'
    ACH_OUTGOING_CREDIT_SWEEP = 'ACH_OUTGOING_CREDIT_SWEEP'
    ACH_OUTGOING_CREDIT_SWEEP_REVERSAL = 'ACH_OUTGOING_CREDIT_SWEEP_REVERSAL'
    ACH_OUTGOING_DEBIT_SWEEP = 'ACH_OUTGOING_DEBIT_SWEEP'
    ACH_OUTGOING_DEBIT_SWEEP_REVERSAL = 'ACH_OUTGOING_DEBIT_SWEEP_REVERSAL'
    ACH_OUTGOING_RETURN_CREDIT_SWEEP = 'ACH_OUTGOING_RETURN_CREDIT_SWEEP'
    ACH_OUTGOING_RETURN_CREDIT_SWEEP_REVERSAL = 'ACH_OUTGOING_RETURN_CREDIT_SWEEP_REVERSAL'
    ACH_OUTGOING_RETURN_DEBIT_SWEEP = 'ACH_OUTGOING_RETURN_DEBIT_SWEEP'
    ACH_OUTGOING_RETURN_DEBIT_SWEEP_REVERSAL = 'ACH_OUTGOING_RETURN_DEBIT_SWEEP_REVERSAL'
    ACH_SWEEP = 'ACH_SWEEP'
    ACH_SWEEP_REVERSAL = 'ACH_SWEEP_REVERSAL'
    CASHBACK = 'CASHBACK'
    CASHBACK_REVERSAL = 'CASHBACK_REVERSAL'
    CASHBACK_SWEEP = 'CASHBACK_SWEEP'
    CASHBACK_SWEEP_REVERSAL = 'CASHBACK_SWEEP_REVERSAL'
    CREDIT_MEMO = 'CREDIT_MEMO'
    CREDIT_MEMO_REVERSAL = 'CREDIT_MEMO_REVERSAL'
    DOMESTIC_WIRE_INCOMING_RETURN_SWEEP = 'DOMESTIC_WIRE_INCOMING_RETURN_SWEEP'
    DOMESTIC_WIRE_INCOMING_RETURN_SWEEP_REVERSAL = 'DOMESTIC_WIRE_INCOMING_RETURN_SWEEP_REVERSAL'
    DOMESTIC_WIRE_INCOMING_SWEEP = 'DOMESTIC_WIRE_INCOMING_SWEEP'
    DOMESTIC_WIRE_INCOMING_SWEEP_REVERSAL = 'DOMESTIC_WIRE_INCOMING_SWEEP_REVERSAL'
    DOMESTIC_WIRE_OUTGOING_RETURN_SWEEP = 'DOMESTIC_WIRE_OUTGOING_RETURN_SWEEP'
    DOMESTIC_WIRE_OUTGOING_RETURN_SWEEP_REVERSAL = 'DOMESTIC_WIRE_OUTGOING_RETURN_SWEEP_REVERSAL'
    DOMESTIC_WIRE_OUTGOING_SWEEP = 'DOMESTIC_WIRE_OUTGOING_SWEEP'
    DOMESTIC_WIRE_OUTGOING_SWEEP_REVERSAL = 'DOMESTIC_WIRE_OUTGOING_SWEEP_REVERSAL'
    EXCHANGE_RATE_DIFFERENCE_GAIN = 'EXCHANGE_RATE_DIFFERENCE_GAIN'
    EXCHANGE_RATE_DIFFERENCE_GAIN_REVERSAL = 'EXCHANGE_RATE_DIFFERENCE_GAIN_REVERSAL'
    EXCHANGE_RATE_DIFFERENCE_LOSS = 'EXCHANGE_RATE_DIFFERENCE_LOSS'
    EXCHANGE_RATE_DIFFERENCE_LOSS_REVERSAL = 'EXCHANGE_RATE_DIFFERENCE_LOSS_REVERSAL'
    FEE = 'FEE'
    FEE_REVERSAL = 'FEE_REVERSAL'
    FEE_SWEEP = 'FEE_SWEEP'
    FEE_SWEEP_REVERSAL = 'FEE_SWEEP_REVERSAL'
    FORCE_PAYMENT = 'FORCE_PAYMENT'
    FORCE_PAYMENT_REVERSAL = 'FORCE_PAYMENT_REVERSAL'
    INCOMING_WIRE = 'INCOMING_WIRE'
    INCOMING_WIRE_REVERSAL = 'INCOMING_WIRE_REVERSAL'
    INCOMING_WIRE_SWEEP = 'INCOMING_WIRE_SWEEP'
    INCOMING_WIRE_SWEEP_REVERSAL = 'INCOMING_WIRE_SWEEP_REVERSAL'
    INTEREST_CHARGED = 'INTEREST_CHARGED'
    INTEREST_CHARGED_REVERSAL = 'INTEREST_CHARGED_REVERSAL'
    INTEREST_CHARGED_SWEEP = 'INTEREST_CHARGED_SWEEP'
    INTEREST_CHARGED_SWEEP_REVERSAL = 'INTEREST_CHARGED_SWEEP_REVERSAL'
    INTEREST_PAYOUT = 'INTEREST_PAYOUT'
    INTEREST_PAYOUT_REVERSAL = 'INTEREST_PAYOUT_REVERSAL'
    INTEREST_PAYOUT_SWEEP = 'INTEREST_PAYOUT_SWEEP'
    INTEREST_PAYOUT_SWEEP_REVERSAL = 'INTEREST_PAYOUT_SWEEP_REVERSAL'
    INTERNATIONAL_WIRE_OUTGOING_SWEEP = 'INTERNATIONAL_WIRE_OUTGOING_SWEEP'
    INTERNATIONAL_WIRE_OUTGOING_SWEEP_REVERSAL = 'INTERNATIONAL_WIRE_OUTGOING_SWEEP_REVERSAL'
    INVOICE = 'INVOICE'
    INVOICE_REVERSAL = 'INVOICE_REVERSAL'
    JIT_FUND = 'JIT_FUND'
    JIT_FUND_REVERSAL = 'JIT_FUND_REVERSAL'
    LOAN_DISBURSEMENT = 'LOAN_DISBURSEMENT'
    LOAN_DISBURSEMENT_REVERSAL = 'LOAN_DISBURSEMENT_REVERSAL'
    LOAN_FUNDING = 'LOAN_FUNDING'
    LOAN_FUNDING_REVERSAL = 'LOAN_FUNDING_REVERSAL'
    LOC_USAGE = 'LOC_USAGE'
    LOC_USAGE_REVERSAL = 'LOC_USAGE_REVERSAL'
    MANUAL_ADJUSTMENT = 'MANUAL_ADJUSTMENT'
    MANUAL_ADJUSTMENT_REVERSAL = 'MANUAL_ADJUSTMENT_REVERSAL'
    MANUAL_ADJUSTMENT_SWEEP = 'MANUAL_ADJUSTMENT_SWEEP'
    MANUAL_ADJUSTMENT_SWEEP_REVERSAL = 'MANUAL_ADJUSTMENT_SWEEP_REVERSAL'
    MANUAL_CARD_SWEEP = 'MANUAL_CARD_SWEEP'
    MANUAL_CARD_SWEEP_REVERSAL = 'MANUAL_CARD_SWEEP_REVERSAL'
    MANUAL_CHECK_SWEEP = 'MANUAL_CHECK_SWEEP'
    MANUAL_CHECK_SWEEP_REVERSAL = 'MANUAL_CHECK_SWEEP_REVERSAL'
    MANUAL_WIRE_SWEEP = 'MANUAL_WIRE_SWEEP'
    MANUAL_WIRE_SWEEP_REVERSAL = 'MANUAL_WIRE_SWEEP_REVERSAL'
    MASTERCARD_GROSS_SWEEP = 'MASTERCARD_GROSS_SWEEP'
    MASTERCARD_GROSS_SWEEP_REVERSAL = 'MASTERCARD_GROSS_SWEEP_REVERSAL'
    MASTERCARD_INTERCHANGE_SWEEP = 'MASTERCARD_INTERCHANGE_SWEEP'
    MASTERCARD_INTERCHANGE_SWEEP_REVERSAL = 'MASTERCARD_INTERCHANGE_SWEEP_REVERSAL'
    MASTERCARD_NET_SWEEP = 'MASTERCARD_NET_SWEEP'
    MASTERCARD_NET_SWEEP_REVERSAL = 'MASTERCARD_NET_SWEEP_REVERSAL'
    MOBILE_DEPOSIT_RETURN_SWEEP = 'MOBILE_DEPOSIT_RETURN_SWEEP'
    MOBILE_DEPOSIT_RETURN_SWEEP_REVERSAL = 'MOBILE_DEPOSIT_RETURN_SWEEP_REVERSAL'
    MOBILE_DEPOSIT_SWEEP = 'MOBILE_DEPOSIT_SWEEP'
    MOBILE_DEPOSIT_SWEEP_REVERSAL = 'MOBILE_DEPOSIT_SWEEP_REVERSAL'
    NETWORK_ADJUSTMENT_SWEEP = 'NETWORK_ADJUSTMENT_SWEEP'
    NETWORK_ADJUSTMENT_SWEEP_REVERSAL = 'NETWORK_ADJUSTMENT_SWEEP_REVERSAL'
    NETWORK_CHARGEBACK_SWEEP = 'NETWORK_CHARGEBACK_SWEEP'
    NETWORK_CHARGEBACK_SWEEP_REVERSAL = 'NETWORK_CHARGEBACK_SWEEP_REVERSAL'
    OUTGOING_INTERNATIONAL_REMITTANCE = 'OUTGOING_INTERNATIONAL_REMITTANCE'
    OUTGOING_INTERNATIONAL_REMITTANCE_REVERSAL = 'OUTGOING_INTERNATIONAL_REMITTANCE_REVERSAL'
    PROGRAM_DECREASE = 'PROGRAM_DECREASE'
    PROGRAM_DECREASE_REVERSAL = 'PROGRAM_DECREASE_REVERSAL'
    PROGRAM_EXPANSION = 'PROGRAM_EXPANSION'
    PROGRAM_EXPANSION_REVERSAL = 'PROGRAM_EXPANSION_REVERSAL'
    PROMOTIONAL_CREDIT = 'PROMOTIONAL_CREDIT'
    PROMOTIONAL_CREDIT_REVERSAL = 'PROMOTIONAL_CREDIT_REVERSAL'
    PROMOTIONAL_CREDIT_SWEEP = 'PROMOTIONAL_CREDIT_SWEEP'
    PROMOTIONAL_CREDIT_SWEEP_REVERSAL = 'PROMOTIONAL_CREDIT_SWEEP_REVERSAL'
    PULSE_GROSS_SWEEP = 'PULSE_GROSS_SWEEP'
    PULSE_GROSS_SWEEP_REVERSAL = 'PULSE_GROSS_SWEEP_REVERSAL'
    PULSE_INTERCHANGE_SWEEP = 'PULSE_INTERCHANGE_SWEEP'
    PULSE_INTERCHANGE_SWEEP_REVERSAL = 'PULSE_INTERCHANGE_SWEEP_REVERSAL'
    REPAYMENT = 'REPAYMENT'
    REPAYMENT_REVERSAL = 'REPAYMENT_REVERSAL'
    SECURITY_ACCOUNT_PAYMENT = 'SECURITY_ACCOUNT_PAYMENT'
    SECURITY_ACCOUNT_PAYMENT_REVERSAL = 'SECURITY_ACCOUNT_PAYMENT_REVERSAL'
    SIGN_UP_BONUS = 'SIGN_UP_BONUS'
    SIGN_UP_BONUS_REVERSAL = 'SIGN_UP_BONUS_REVERSAL'
    SUBSCRIPTION_FEE = 'SUBSCRIPTION_FEE'
    SUBSCRIPTION_FEE_REVERSAL = 'SUBSCRIPTION_FEE_REVERSAL'
    TRANSFER_FEE = 'TRANSFER_FEE'
    TRANSFER_FEE_REVERSAL = 'TRANSFER_FEE_REVERSAL'
    TRANSFER_FEE_REVERSAL_REVERSAL = 'TRANSFER_FEE_REVERSAL_REVERSAL'

    @classmethod
    def from_json(cls, json_str: str) -> InternalTransferTransactionSubtypes:
        """Create an instance of InternalTransferTransactionSubtypes from a JSON string"""
        return InternalTransferTransactionSubtypes(json.loads(json_str))


