# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 1.41.3
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr
from synctera_client_v1.models.dc_sign import DcSign

class TransactionLineV0(BaseModel):
    """
    TransactionLineV0
    """
    account_id: StrictStr = Field(..., description="The account uuid associated with this transaction line")
    account_no: StrictStr = Field(..., description="The account number associated with this transaction line")
    amount: StrictInt = Field(..., description="The amount (in ISO 4217 minor currency units) of the transaction")
    currency: StrictStr = Field(..., description="ISO 4217 alphabetic currency code of the transfer amount")
    dc_sign: DcSign = Field(...)
    uuid: StrictStr = Field(...)
    __properties = ["account_id", "account_no", "amount", "currency", "dc_sign", "uuid"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TransactionLineV0:
        """Create an instance of TransactionLineV0 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TransactionLineV0:
        """Create an instance of TransactionLineV0 from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TransactionLineV0.parse_obj(obj)

        _obj = TransactionLineV0.parse_obj({
            "account_id": obj.get("account_id"),
            "account_no": obj.get("account_no"),
            "amount": obj.get("amount"),
            "currency": obj.get("currency"),
            "dc_sign": obj.get("dc_sign"),
            "uuid": obj.get("uuid")
        })
        return _obj

