# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 1.41.3
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, constr, validator
from synctera_client_v1.models.create_transfer_type import CreateTransferType
from synctera_client_v1.models.merchant import Merchant

class CreateTransferResponsePull(BaseModel):
    """
    CreateTransferResponsePull
    """
    three_ds_id: Optional[StrictStr] = Field(None, description="Unique identifier of an External Card Transfer 3-D Secure Authorization - conditionally required according to your program's 3DS policy")
    type: CreateTransferType = Field(...)
    account_id: StrictStr = Field(..., description="The ID of the Synctera account into which or from which funds were moved")
    amount: StrictInt = Field(..., description="Amount of the transfer in cents")
    creation_time: datetime = Field(...)
    currency: constr(strict=True, max_length=3, min_length=3) = Field(..., description="ISO 4217  Alpha-3 currency code")
    customer_id: StrictStr = Field(..., description="The ID of the customer to whom the card belongs")
    external_card_id: StrictStr = Field(..., description="The ID of the external card from/to which the transfer was initiated/received")
    id: StrictStr = Field(..., description="The ID of the transfer")
    last_updated_time: datetime = Field(...)
    merchant: Merchant = Field(...)
    status: StrictStr = Field(..., description="The status of the transfer")
    tenant: StrictStr = Field(..., description="The id of the tenant containing the resource. ")
    transaction_id: Optional[StrictStr] = Field(None, description="The transaction ID")
    __properties = ["three_ds_id", "type", "account_id", "amount", "creation_time", "currency", "customer_id", "external_card_id", "id", "last_updated_time", "merchant", "status", "tenant", "transaction_id"]

    @validator('status')
    def status_validate_enum(cls, v):
        if v not in ('CANCELED', 'DECLINED', 'PENDING', 'SUCCEEDED', 'UNKNOWN'):
            raise ValueError("must be one of enum values ('CANCELED', 'DECLINED', 'PENDING', 'SUCCEEDED', 'UNKNOWN')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreateTransferResponsePull:
        """Create an instance of CreateTransferResponsePull from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of merchant
        if self.merchant:
            _dict['merchant'] = self.merchant.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreateTransferResponsePull:
        """Create an instance of CreateTransferResponsePull from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CreateTransferResponsePull.parse_obj(obj)

        _obj = CreateTransferResponsePull.parse_obj({
            "three_ds_id": obj.get("three_ds_id"),
            "type": obj.get("type"),
            "account_id": obj.get("account_id"),
            "amount": obj.get("amount"),
            "creation_time": obj.get("creation_time"),
            "currency": obj.get("currency"),
            "customer_id": obj.get("customer_id"),
            "external_card_id": obj.get("external_card_id"),
            "id": obj.get("id"),
            "last_updated_time": obj.get("last_updated_time"),
            "merchant": Merchant.from_dict(obj.get("merchant")) if obj.get("merchant") is not None else None,
            "status": obj.get("status"),
            "tenant": obj.get("tenant"),
            "transaction_id": obj.get("transaction_id")
        })
        return _obj

