# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 1.41.3
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictInt, StrictStr, confloat, conint, conlist, validator
from synctera_client_v1.models.income import Income

class FinancialStatus(BaseModel):
    """
    Financial status of the applicant. Only applicable for customers. 
    """
    debt_to_income_ratio: Optional[Union[confloat(le=100, ge=0, strict=True), conint(le=100, ge=0, strict=True)]] = Field(None, description="Debt-to-income ratio. It is between 0% and 100% and allows for decimals")
    employment_status: Optional[StrictStr] = Field(None, description="Employment status of the applicant")
    income: Optional[conlist(Income)] = None
    monthly_rent_mortgage: Optional[StrictInt] = Field(None, description="Monthly rent/mortgage in cents, i.e. $2200 is represented as 220000")
    __properties = ["debt_to_income_ratio", "employment_status", "income", "monthly_rent_mortgage"]

    @validator('employment_status')
    def employment_status_validate_enum(cls, v):
        if v is None:
            return v
        if v not in ('EMPLOYED', 'OTHER', 'SELF-EMPLOYED'):
            raise ValueError("must be one of enum values ('EMPLOYED', 'OTHER', 'SELF-EMPLOYED')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FinancialStatus:
        """Create an instance of FinancialStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in income (list)
        _items = []
        if self.income:
            for _item in self.income:
                if _item:
                    _items.append(_item.to_dict())
            _dict['income'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FinancialStatus:
        """Create an instance of FinancialStatus from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return FinancialStatus.parse_obj(obj)

        _obj = FinancialStatus.parse_obj({
            "debt_to_income_ratio": obj.get("debt_to_income_ratio"),
            "employment_status": obj.get("employment_status"),
            "income": [Income.from_dict(_item) for _item in obj.get("income")] if obj.get("income") is not None else None,
            "monthly_rent_mortgage": obj.get("monthly_rent_mortgage")
        })
        return _obj

